summaryrefslogtreecommitdiffstats
path: root/libkpgp/kpgpkey.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /libkpgp/kpgpkey.cpp
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkpgp/kpgpkey.cpp')
-rw-r--r--libkpgp/kpgpkey.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/libkpgp/kpgpkey.cpp b/libkpgp/kpgpkey.cpp
index d0d2e4ec..8a8ed48b 100644
--- a/libkpgp/kpgpkey.cpp
+++ b/libkpgp/kpgpkey.cpp
@@ -23,23 +23,23 @@ namespace Kpgp {
/* member functions of Kpgp::KeyIDList --------------------------------- */
/** Converts from a KeyIDList to a QStringList.
*/
-QStringList KeyIDList::toStringList() const
+TQStringList KeyIDList::toStringList() const
{
- QStringList res;
+ TQStringList res;
for( KeyIDList::ConstIterator it = begin(); it != end(); ++it ) {
res << (*it).data();
}
return res;
}
/** Converts from a QStringList to a KeyIDList.
*/
-KeyIDList KeyIDList::fromStringList( const QStringList& l )
+KeyIDList KeyIDList::fromStringList( const TQStringList& l )
{
KeyIDList res;
- for( QStringList::ConstIterator it = l.begin(); it != l.end(); ++it ) {
+ for( TQStringList::ConstIterator it = l.begin(); it != l.end(); ++it ) {
res << (*it).local8Bit();
}
return res;
@@ -47,7 +47,7 @@ KeyIDList KeyIDList::fromStringList( const QStringList& l )
/* member functions of Kpgp::UserID ------------------------------------ */
-UserID::UserID(const QString& str, const Validity validity,
+UserID::UserID(const TQString& str, const Validity validity,
const bool revoked, const bool invalid)
{
mText = str;
@@ -81,7 +81,7 @@ Subkey::Subkey(const KeyID& keyID, const bool secret)
/* member functions of Kpgp::Key --------------------------------------- */
-Key::Key(const KeyID& keyid, const QString& uid, const bool secret) :
+Key::Key(const KeyID& keyid, const TQString& uid, const bool secret) :
mSubkeys(), mUserIDs()
{
mSecret = secret;
@@ -145,7 +145,7 @@ Key::keyTrust() const
}
Validity
-Key::keyTrust( const QString& uid ) const
+Key::keyTrust( const TQString& uid ) const
{
Validity trust = KPGP_VALIDITY_UNKNOWN;
@@ -194,7 +194,7 @@ Key::isValidSigningKey() const
}
-void Key::addUserID(const QString &uid, const Validity validity,
+void Key::addUserID(const TQString &uid, const Validity validity,
const bool revoked, const bool invalid)
{
if (!uid.isEmpty()) {
@@ -203,7 +203,7 @@ void Key::addUserID(const QString &uid, const Validity validity,
}
}
-bool Key::matchesUserID(const QString& str, bool cs)
+bool Key::matchesUserID(const TQString& str, bool cs)
{
if (str.isEmpty() || mUserIDs.isEmpty())
return false;
@@ -246,7 +246,7 @@ Subkey *Key::getSubkey(const KeyID& keyID)
return 0;
}
-void Key::setFingerprint(const KeyID& keyID, const QCString &fpr)
+void Key::setFingerprint(const KeyID& keyID, const TQCString &fpr)
{
Subkey *key;
if ((key = getSubkey(keyID)) != 0) {
@@ -23,23 +23,23 @@ namespace Kpgp {
/* member functions of Kpgp::KeyIDList --------------------------------- */
-/** Converts from a KeyIDList to a QStringList.
+/** Converts from a KeyIDList to a TQStringList.
*/
@@ -23,23 +23,23 @@ namespace Kpgp {
return res;
}
-/** Converts from a QStringList to a KeyIDList.
+/** Converts from a TQStringList to a KeyIDList.
*/